render_site_index_html_with_title

Function render_site_index_html_with_title 

pub fn render_site_index_html_with_title(
    files: &[DocFile],
    title: &str,
) -> String
Render the top-level site index with a custom page title (ADR-0092: gruel doc uses the manifest name here when one is present).